==> ui-react-1.0.84.tgz: package/esm/ImageList/ImageList.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["version", "gap", "rowGap", "columnGap", "columns", "Component", "className", "style", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is, unique } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import useMediaQuery from '../useMediaQuery';
import { valueBreakpoints, staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    listStyleType: 'none'
  },
  version_standard: {
    display: 'grid'
  },
  version_quilted: {
    display: 'grid'
  },
  version_vowen: {
    display: 'grid',
    '& > *:nth-of-type(2n)': {
      height: '70%',
      overflow: 'hidden',
      alignSelf: 'center'
    }
  },
  version_masonry: {
    display: 'block'
  }
}), {
  name: 'onesy-ImageList'
});
const ImageList = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyImageList?.props?.default), props_), [props_]);
  const {
    classes
  } = useStyle();
  const {
      version = 'standard',
      gap: gap_,
      rowGap: rowGap_,
      columnGap: columnGap_,
      columns: columns_,
      Component = 'ul',
      className,
      style,
      children
    } = props,
    otherProps = _objectWithoutProperties(props, _excluded);
  const other = otherProps;
  const refs = {
    root: React.useRef(undefined)
  };
  const keys = React.useMemo(() => {
    const result = [];
    const items = [gap_, rowGap_, columnGap_, columns_];
    items.forEach(item => {
      if (is('object', item)) Object.keys(item).filter(key => theme.breakpoints.media[key]).forEach(key => result.push(key));
    });
    return unique(result);
  }, [gap_, rowGap_, columnGap_, columns_]);
  const breakpoints = {};
  keys.forEach(key => {
    breakpoints[key] = useMediaQuery(theme.breakpoints.media[key], {
      element: refs.root.current
    });
  });
  const gap = valueBreakpoints(gap_, 0.5, breakpoints, theme);
  const rowGap = valueBreakpoints(rowGap_, undefined, breakpoints, theme);
  const columnGap = valueBreakpoints(columnGap_, undefined, breakpoints, theme);
  const columns = valueBreakpoints(columns_, {
    400: 1,
    500: 2,
    700: 3,
    1100: 4,
    1400: 5,
    1700: 6,
    2000: 7,
    default: 4
  }, breakpoints, theme);
  const styles = {
    root: {},
    item: {}
  };
  if (['standard', 'quilted', 'vowen'].includes(version)) {
    styles.root.gridTemplateColumns = `repeat(${columns}, 1fr)`;
  }
  if (version === 'masonry') styles.root.columnCount = columns;
  if (rowGap !== undefined || columnGap !== undefined) {
    if (rowGap !== undefined) {
      styles.root.rowGap = `${rowGap}px`;
      if (version === 'masonry') styles.item.marginBottom = `${rowGap * theme.space.unit}px`;
    }
    if (columnGap !== undefined) styles.root.columnGap = `${columnGap * theme.space.unit}px`;
  } else {
    styles.root.gap = `${gap * theme.space.unit}px`;
    if (version === 'masonry') styles.item.marginBottom = `${gap * theme.space.unit}px`;
  }
  const Wrapper = version !== 'masonry' ? React.Fragment : 'div';
  const WrapperProps = {};
  if (version === 'masonry') {
    WrapperProps.ref = item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    };
    WrapperProps.style = _objectSpread({}, style);
    other.style = _objectSpread({}, styles.root);
  } else {
    other.ref = item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    };
    other.style = _objectSpread(_objectSpread({}, styles.root), style);
  }
  return /*#__PURE__*/React.createElement(Wrapper, WrapperProps, /*#__PURE__*/React.createElement(Component, _extends({
    className: classNames([staticClassName('ImageList', theme) && [`onesy-ImageList-root`], className, classes.root, classes[`version_${version}`]])
  }, other), React.Children.toArray(children).map((item, index) => (/*#__PURE__*/React.cloneElement(item, {
    key: index,
    version,
    style: _objectSpread(_objectSpread({}, styles.item), item.props.style)
  })))));
});
ImageList.displayName = 'onesy-ImageList';
export default ImageList;

==> ui-react-1.1.440.tgz: package/esm/ImageList/ImageList.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["version", "gap", "rowGap", "columnGap", "columns", "Component", "className", "style", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import useMediaQuery from '../useMediaQuery';
import { valueBreakpoints, staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    listStyleType: 'none'
  },
  version_standard: {
    display: 'grid'
  },
  version_quilted: {
    display: 'grid'
  },
  version_vowen: {
    display: 'grid',
    '& > *:nth-of-type(2n)': {
      height: '70%',
      overflow: 'hidden',
      alignSelf: 'center'
    }
  },
  version_masonry: {
    display: 'block'
  }
}), {
  name: 'amaui-ImageList'
});
const ImageList = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiImageList?.props?.default), props_), [props_]);
  const {
    classes
  } = useStyle();
  const {
      version = 'standard',
      gap: gap_,
      rowGap: rowGap_,
      columnGap: columnGap_,
      columns: columns_,
      Component = 'ul',
      className,
      style,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const refs = {
    root: React.useRef()
  };
  const breakpoints = {};
  theme.breakpoints.keys.forEach(key => {
    if (theme.breakpoints.media[key]) breakpoints[key] = useMediaQuery(theme.breakpoints.media[key], {
      element: refs.root.current
    });
  });
  const gap = valueBreakpoints(gap_, 0.5, breakpoints, theme);
  const rowGap = valueBreakpoints(rowGap_, undefined, breakpoints, theme);
  const columnGap = valueBreakpoints(columnGap_, undefined, breakpoints, theme);
  const columns = valueBreakpoints(columns_, {
    xxs: 1,
    xs: 2,
    sm: 3,
    md: 4,
    lg: 5,
    xl: 6,
    xxl: 7,
    default: 4
  }, breakpoints, theme);
  const styles = {
    root: {},
    item: {}
  };
  if (['standard', 'quilted', 'vowen'].includes(version)) {
    styles.root.gridTemplateColumns = `repeat(${columns}, 1fr)`;
  }
  if (version === 'masonry') styles.root.columnCount = columns;
  if (rowGap !== undefined || columnGap !== undefined) {
    if (rowGap !== undefined) {
      styles.root.rowGap = `${rowGap}px`;
      if (version === 'masonry') styles.item.marginBottom = `${rowGap * theme.space.unit}px`;
    }
    if (columnGap !== undefined) styles.root.columnGap = `${columnGap * theme.space.unit}px`;
  } else {
    styles.root.gap = `${gap * theme.space.unit}px`;
    if (version === 'masonry') styles.item.marginBottom = `${gap * theme.space.unit}px`;
  }
  const Wrapper = version !== 'masonry' ? React.Fragment : 'div';
  const WrapperProps = {};
  if (version === 'masonry') {
    WrapperProps.ref = item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    };
    WrapperProps.style = _objectSpread({}, style);
    other.style = _objectSpread({}, styles.root);
  } else {
    other.ref = item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    };
    other.style = _objectSpread(_objectSpread({}, styles.root), style);
  }
  return /*#__PURE__*/React.createElement(Wrapper, WrapperProps, /*#__PURE__*/React.createElement(Component, _extends({
    className: classNames([staticClassName('ImageList', theme) && [`amaui-ImageList-root`], className, classes.root, classes[`version_${version}`]])
  }, other), React.Children.toArray(children).map((item, index) => /*#__PURE__*/React.cloneElement(item, {
    key: index,
    version,
    style: _objectSpread(_objectSpread({}, styles.item), item.props.style)
  }))));
});
ImageList.displayName = 'amaui-ImageList';
export default ImageList;
